using System;
using System.Xml;

namespace NsBusinessLogic
{
	/* This class generates xml document as shown below:
	 * 
	<OrderDeliveryReport>

	  <Order OrderId="1" Customer="Varian" Address="679 Springvale Rd, Mulgrave, Vic 3150, Australia" OrderDate="7/10/2003">
		<Product Id="3" Description="MP3 player flash memory 64M" OrderQty="30">
		  <Delivery Qty="10" Date="12/10/2003" />
		  <Delivery Qty="12" Date="17/10/2003" />
		</Product>
		<Product Id="5" Description="MP3 player flash memory FM radio 256M" OrderQty="25">
		  <Delivery Qty="10" Date="12/10/2003" />
		  <Delivery Qty="10" Date="17/10/2003" />
		  <Delivery Qty="15" Date="21/10/2003" />
		</Product>
	  </Order>
  
	  <Order OrderId="2" Customer="Microsoft" Address="1 Microsoft way, Redmond, WA 98052, US" OrderDate="24/11/2003">
		<Product Id="4" Description="MP3 player flash memory 128M" OrderQty="13">
		  <Delivery Qty="10" Date="3/12/2003" />
		  <Delivery Qty="3" Date="11/12/2003" />
		</Product>
		<Product Id="6" Description="MP3 player hard drive 1G" OrderQty="4">
		  <Delivery Qty="2" Date="11/12/2003" />
		</Product>
	  </Order>
  
	</OrderDeliveryReport>	 
	*/

	public class OrderDeliveryReport
	{
		private XmlDocument mDoc = new XmlDocument();

		public OrderDeliveryReport()
		{
			mDoc.LoadXml("<OrderDeliveryReport/>");
		}

		public XmlNode AddOrderElement(int iOrderId, string strCustomer, string strAddress, DateTime orderDate)
		{
			XmlElement elem = mDoc.CreateElement("Order");
			XmlNode orderNode = mDoc.DocumentElement.AppendChild(elem);

			XmlAttribute attrib = mDoc.CreateAttribute("OrderId");
			attrib.Value = Convert.ToString(iOrderId);
			elem.Attributes.Append(attrib);

			attrib = mDoc.CreateAttribute("Customer");
			attrib.Value = strCustomer;
			elem.Attributes.Append(attrib);

			attrib = mDoc.CreateAttribute("Address");
			attrib.Value = strAddress;
			elem.Attributes.Append(attrib);

			attrib = mDoc.CreateAttribute("OrderDate");
			attrib.Value = orderDate.ToShortDateString();
			elem.Attributes.Append(attrib);

			return orderNode;
		}

		public XmlNode AddProductElement(XmlNode orderNode, int iProductId, string strDescrip, int iOrderQty)
		{
			XmlElement elem = mDoc.CreateElement("Product");
			XmlNode productNode = orderNode.AppendChild(elem);

			XmlAttribute attrib = mDoc.CreateAttribute("Id");
			attrib.Value = Convert.ToString(iProductId);
			elem.Attributes.Append(attrib);

			attrib = mDoc.CreateAttribute("Description");
			attrib.Value = strDescrip;
			elem.Attributes.Append(attrib);

			attrib = mDoc.CreateAttribute("OrderQty");
			attrib.Value = Convert.ToString(iOrderQty);
			elem.Attributes.Append(attrib);

			return productNode;
		}

		public void AddDeliveryElementToProductElement(XmlNode productNode, int iDeliveredQty, DateTime deliveryDate)
		{
			XmlElement elem = mDoc.CreateElement("Delivery");
			productNode.AppendChild(elem);

			XmlAttribute attrib = mDoc.CreateAttribute("Qty");
			attrib.Value = Convert.ToString(iDeliveredQty);
			elem.Attributes.Append(attrib);

			attrib = mDoc.CreateAttribute("Date");
			attrib.Value = deliveryDate.ToShortDateString();
			elem.Attributes.Append(attrib);
		}

		public void Save(string strFilePath)
		{
			mDoc.Save(strFilePath);
		}

		public string GetXmlString()
		{
			return mDoc.OuterXml;
		}
	}
}
