using System;
using System.Collections;

namespace NsBusinessLogic
{
	public class Product
	{
		protected NsPersistent.PProduct mPersistent = null;

		public Product(int iProductId, string strDescrip, int iYieldTime, Decimal dcPrice, int iStdStockQty, int iStockedQty)
		{
			mPersistent = new NsPersistent.PProduct(strDescrip, dcPrice, iStockedQty);
		}

		public Product(NsPersistent.PProduct persistent)
		{
			mPersistent = persistent;
		}


		//******************** Business logic methods ******************

		/// <summary>
		/// To deduct stock (when delivering to customer) or increase stock (when new products fabricated).
		/// </summary>
		public void AddStock(int iQty)
		{
			mPersistent.StockedQty += iQty;
		}

		/// <summary>
		/// Called by production component (outside the scope of this application) to place fabrication order.
		/// </summary>
		public int GetPendingQtyForFabrication()
		{
			NsPersistent.POrderItem [] aOrderItems = mPersistent.GetOrderItems();
			int iPendingQty = - mPersistent.StockedQty;

			foreach (NsPersistent.POrderItem orderItem in aOrderItems)
			{
				iPendingQty += orderItem.PendingQty;
			}

			return iPendingQty;
		}


		//**************** Persistent properties & Navigation methods ****************

		public NsPersistent.PProduct Persistent
		{
			get { return mPersistent; }
		}

		public int StockedOty
		{
			get { return mPersistent.StockedQty; }
		}
	}
}
